@@ -4,10 +4,5 @@
 from .utils import is_watchdog_supported
 from .utils import is_watchman_supported
 
-from .reloader import (
-    start_reloader,
-)
-from .worker import (
-    is_active,
-    get_reloader,
-)
+from .reloader import start_reloader
+from .worker import is_active, get_reloader
