@@ -2,12 +2,15 @@ import os
 
 here = os.path.abspath(os.path.dirname(__file__))
 
+
 def make_proxy(monitor_factory, logger):
     from hupper.reloader import FileMonitorProxy
+
     proxy = FileMonitorProxy(logger)
     proxy.monitor = monitor_factory(proxy.file_changed)
     return proxy
 
+
 def test_proxy_proxies(logger):
     class DummyMonitor(object):
         started = stopped = joined = False
@@ -34,6 +37,7 @@ def test_proxy_proxies(logger):
     proxy.stop()
     assert monitor.stopped and monitor.joined
 
+
 def test_proxy_expands_paths(tmpdir, logger):
     class DummyMonitor(object):
         def __call__(self, cb, **kw):
@@ -59,6 +63,7 @@ def test_proxy_expands_paths(tmpdir, logger):
         os.path.join(rootdir, 'foo.txt'),
     ]
 
+
 def test_proxy_tracks_changes(logger):
     class DummyMonitor(object):
         def __call__(self, cb, **kw):
@@ -83,3 +88,26 @@ def test_proxy_tracks_changes(logger):
     out = logger.get_output('info')
     assert out == 'foo.txt changed; reloading ...'
     logger.reset()
+
+
+def test_ignore_files():
+    class DummyMonitor(object):
+        paths = set()
+
+        def add_path(self, path):
+            self.paths.add(path)
+
+    from hupper.reloader import FileMonitorProxy
+
+    proxy = FileMonitorProxy(None, {'/a/*'})
+    monitor = proxy.monitor = DummyMonitor()
+
+    path = 'foo.txt'
+    assert path not in monitor.paths
+    proxy.add_path(path)
+    assert path in monitor.paths
+
+    path = '/a/foo.txt'
+    assert path not in monitor.paths
+    proxy.add_path(path)
+    assert path not in monitor.paths
